==> fantacalciobazar_0.2.tar.gz: fantacalciobazar/inserisci_offerta.php <==
<?php

###############################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
################################################################################

include("controlla_pass.php");
if ($pass_errata != "SI") {




$sostituire = "SI";
$trovato = "NO";
$inserire = "SI";
$soldi_spesi = 0;
$vecchio_proprietario = "";
$nuovo_costo = "";
$num_calciatori_posseduti = 0;
$lock = fopen("mercato.lock","w+");
flock($lock,2);

$calciatori = @file("mercato.txt");
$num_calciatori = count($calciatori);
for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
$dati_calciatore = explode(",", $calciatori[$num1]);
$numero = $dati_calciatore[0];
$proprietario = $dati_calciatore[4];
if ($proprietario == $nome_utente) {
$soldi_spesi = $soldi_spesi + $dati_calciatore[3];
$num_calciatori_posseduti++;
} # fine if ($proprietario == $nome_utente)

if ($num_calciatore == $numero) {
$nome = $dati_calciatore[1];
$ruolo = $dati_calciatore[2];
$trovato = "SI";
$posizione = $num1;
$costo = $dati_calciatore[3];
$proprietario_vero = $proprietario;
$vecchio_proprietario = $dati_calciatore[6];
$vecchio_costo = $dati_calciatore[7];
$vecchio_costo = ereg_replace("\n","",$vecchio_costo);
$nuovo_costo = $dati_calciatore[8];
$nuovo_costo = ereg_replace("\n","",$nuovo_costo);
$tempo_off = $dati_calciatore[5];
$anno_off = substr($tempo_off,0,4);
$mese_off = substr($tempo_off,4,2);
$giorno_off = substr($tempo_off,6,2);
$ora_off = substr($tempo_off,8,2);
$minuto_off = substr($tempo_off,10,2);
$adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
$sec_restanti = mktime($ora_off+$aspetta_ore,$minuto_off+$aspetta_minuti,0,$mese_off,$giorno_off+$aspetta_giorni,$anno_off) - $adesso;
if ($sec_restanti < 0) {
$inserire = "NO";
$frase .= "Tempo scaduto per questa offerta!<br>";
} # fine if ($sec_restanti < 0)
if ($nuovo_costo) { $costo_mostra = $nuovo_costo; }
else { $costo_mostra = $costo; }
if ($costo_mostra >= $valore_offerta) {
$inserire = "NO";
$frase .= "L'offerta non  abbastanza alta per comprare il calciatore.<br>";
} # fine if ($costo >= $valore_offerta)
} # fine if ($num_calciatore == $numero)
} # fine for $num1

if ($trovato != "SI") {
$sostituire = "NO";
$calciatori_completi = file("calciatori.txt");
$num_calciatori_completi = count($calciatori_completi);
for ($num1 = 0 ; $num1 < $num_calciatori_completi ; $num1++) {
$dati_calciatore = explode($separatore_campi_file_calciatori, $calciatori_completi[$num1]);
$numero = $dati_calciatore[($num_colonna_numcalciatore_file_calciatori-1)];
$numero = ereg_replace("\n","",$numero);
if ($num_calciatore == $numero) {
$trovato = "SI";
$nome = $dati_calciatore[($num_colonna_nome_file_calciatori-1)];
$nome = ereg_replace("\n","",$nome);
$nome = ereg_replace("\"","",$nome);
$ruolo = $dati_calciatore[($num_colonna_ruolo_file_calciatori-1)];
$ruolo = ereg_replace("\n","",$ruolo);
if ($ruolo == $simbolo_portiere_file_calciatori) $ruolo = "P";
if ($ruolo == $simbolo_difensore_file_calciatori) $ruolo = "D";
if ($ruolo == $simbolo_centrocampista_file_calciatori) $ruolo = "C";
if ($ruolo == $simbolo_attaccante_file_calciatori) $ruolo = "A";
} # fine if ($num_calciatore == $numero)
} # fine for $num1
} # fine if ($trovato != "SI")

if ($trovato != "SI") {
$inserire = "NO";
$frase .= "Calciatore inesistente, sei un BARO!<br>";
} # fine if ($trovato != "SI")

$verifica_num = ereg_replace("[0-9]","",$valore_offerta);
if ($verifica_num != "") {
$inserire = "NO";
$frase .= "L'offerta deve essere un numero intero.<br>";
} # fine if ($verifica_num != "")

$num_calciatori_comprabili = $max_calciatori - $num_calciatori_posseduti;
$surplus = @file("squadra_$nome_utente");
$surplus = $surplus[0];
if ($vecchio_proprietario == $nome_utente and $vecchio_proprietario != $proprietario_vero) {
$surplus = $surplus - $costo + $vecchio_costo;
} # fine if ($vecchio_proprietario == $nome_utente)
$soldi_spendibili = $soldi_iniziali + $surplus - $soldi_spesi;
if ($num_calciatori_comprabili <= 0) {
$inserire = "NO";
$frase .= "Hai raggiunto il valore massimo di calciatori comperabili.<br>";
} # fine if ($num_calciatori_comprabili <= 0)
if ($soldi_spendibili < $valore_offerta) {
$inserire = "NO";
$frase .= "La tua offerta supera i soldi che hai a disposizione.<br>";
} # fine if ($soldi_spendibili <= $valore_offerta)



if ($inserire == "SI") {
if ($sostituire == "NO") {
$posizione == 0;
$num_calciatori++;
} # fine if ($sostituire == "NO")
$file_mercato = fopen("mercato.txt","w+");
flock($file_mercato,2);
for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {

if ($posizione == $num1) {
$adesso = date("YmdHi");
$linea = "$num_calciatore,$nome,$ruolo,$valore_offerta,$nome_utente,$adesso";

if ($vecchio_proprietario) {
$linea .= ",$vecchio_proprietario,$vecchio_costo";
if ($vecchio_proprietario == $nome_utente) {
if ($vecchio_proprietario != $proprietario_vero) { $aggiungi_surplus = $vecchio_costo - $costo; }
else { $aggiungi_surplus = 0; }
} # fine if ($vecchio_proprietario == $nome_utente)
else {
if ($vecchio_proprietario == $proprietario_vero) {
$aggiungi_surplus = $valore_offerta - $vecchio_costo;
} # fine if ($vecchio_proprietario == $proprietario_vero)
else { $aggiungi_surplus = $valore_offerta - $costo; }
} # fine else if ($vecchio_proprietario == $nome_utente)
$lockutente = fopen("squadra_$vecchio_proprietario.lock","w+");
flock($lockutente,2);
$linee = @file("squadra_$vecchio_proprietario");
$filesquadra = fopen("squadra_$vecchio_proprietario","w+");
flock($filesquadra,2);
$num_linee = count($linee);
if ($num_linee < 1) { $num_linee = 1; }
$nuovo_surplus = $linee[0] + $aggiungi_surplus;
$linee[0] = "$nuovo_surplus
";
rewind($filesquadra);
for ($num2 = 0 ; $num2 < $num_linee ; $num2++) {
fwrite($filesquadra,$linee[$num2]);
} # fine for $num2
flock($filesquadra,3);
flock($lockutente,3);
} # fine if ($vecchio_proprietario)

fwrite($file_mercato,"$linea
");
} # fine if ($posizione == $num1)

else {
if ($sostituire == "NO") { $num_linea = $num1 - 1; }
else { $num_linea = $num1; }
fwrite($file_mercato,$calciatori[$num_linea]);
} # fine else if ($posizione == $num1)
} # fine for $num1
flock($file_mercato,3);
fclose($file_mercato);
echo "<html>
<header>
<title> fantacalcio </title>
<meta http-equiv=\"refresh\" content=\"1; url=mercato.php?nome_utente=$nome_utente&pass_fornita=$pass_fornita\">
</header>
<body bgcolor=#ffffff>
Offerta inserita!";
} # fine if ($inserire == "SI");

else {
echo "<html>
<header>
<title> Fantacalcio </title>
</header>
<body bgcolor=#ffffff>";
echo $frase;
} # fine else if ($inserire == "SI");

echo "<center><form method=\"post\" action=\"mercato.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"torna_mercato\" value=\"Torna al mercato\">
</form></center>";



flock($lock,3);

} # fine if ($pass_errata != "SI")
?>


</body>
</html>

==> fantacalciobazar_0.2.1.tar.gz: fantacalciobazar/inserisci_offerta.php <==
<?php

###############################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
################################################################################

include("controlla_pass.php");
if ($pass_errata != "SI") {




$sostituire = "SI";
$trovato = "NO";
$inserire = "SI";
$soldi_spesi = 0;
$vecchio_proprietario = "";
$nuovo_costo = "";
$num_calciatori_posseduti = 0;
$lock = fopen("mercato.lock","w+");
flock($lock,2);

$calciatori = @file("mercato.txt");
$num_calciatori = count($calciatori);
for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
$dati_calciatore = explode(",", $calciatori[$num1]);
$numero = $dati_calciatore[0];
$proprietario = $dati_calciatore[4];
if ($proprietario == $nome_utente) {
$soldi_spesi = $soldi_spesi + $dati_calciatore[3];
$num_calciatori_posseduti++;
} # fine if ($proprietario == $nome_utente)

if ($num_calciatore == $numero) {
$nome = $dati_calciatore[1];
$ruolo = $dati_calciatore[2];
$trovato = "SI";
$posizione = $num1;
$costo = $dati_calciatore[3];
$proprietario_vero = $proprietario;
$vecchio_proprietario = $dati_calciatore[6];
$vecchio_costo = $dati_calciatore[7];
$vecchio_costo = ereg_replace("
","",$vecchio_costo);
$nuovo_costo = $dati_calciatore[8];
$nuovo_costo = ereg_replace("
","",$nuovo_costo);
$tempo_off = $dati_calciatore[5];
$anno_off = substr($tempo_off,0,4);
$mese_off = substr($tempo_off,4,2);
$giorno_off = substr($tempo_off,6,2);
$ora_off = substr($tempo_off,8,2);
$minuto_off = substr($tempo_off,10,2);
$adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
$sec_restanti = mktime($ora_off+$aspetta_ore,$minuto_off+$aspetta_minuti,0,$mese_off,$giorno_off+$aspetta_giorni,$anno_off) - $adesso;
if ($sec_restanti < 0) {
$inserire = "NO";
$frase .= "Tempo scaduto per questa offerta!<br>";
} # fine if ($sec_restanti < 0)
if ($nuovo_costo) { $costo_mostra = $nuovo_costo; }
else { $costo_mostra = $costo; }
if ($costo_mostra >= $valore_offerta) {
$inserire = "NO";
$frase .= "L'offerta non  abbastanza alta per comprare il calciatore.<br>";
} # fine if ($costo >= $valore_offerta)
} # fine if ($num_calciatore == $numero)
} # fine for $num1

if ($trovato != "SI") {
$sostituire = "NO";
$calciatori_completi = file("calciatori.txt");
$num_calciatori_completi = count($calciatori_completi);
for ($num1 = 0 ; $num1 < $num_calciatori_completi ; $num1++) {
$dati_calciatore = explode($separatore_campi_file_calciatori, $calciatori_completi[$num1]);
$numero = $dati_calciatore[($num_colonna_numcalciatore_file_calciatori-1)];
$numero = ereg_replace("
","",$numero);
if ($num_calciatore == $numero) {
$trovato = "SI";
$nome = $dati_calciatore[($num_colonna_nome_file_calciatori-1)];
$nome = ereg_replace("
","",$nome);
$nome = ereg_replace("\"","",$nome);
$ruolo = $dati_calciatore[($num_colonna_ruolo_file_calciatori-1)];
$ruolo = ereg_replace("
","",$ruolo);
if ($ruolo == $simbolo_portiere_file_calciatori) $ruolo = "P";
if ($ruolo == $simbolo_difensore_file_calciatori) $ruolo = "D";
if ($ruolo == $simbolo_centrocampista_file_calciatori) $ruolo = "C";
if ($ruolo == $simbolo_attaccante_file_calciatori) $ruolo = "A";
} # fine if ($num_calciatore == $numero)
} # fine for $num1
} # fine if ($trovato != "SI")

if ($trovato != "SI") {
$inserire = "NO";
$frase .= "Calciatore inesistente, sei un BARO!<br>";
} # fine if ($trovato != "SI")

$verifica_num = ereg_replace("[0-9]","",$valore_offerta);
if ($verifica_num != "") {
$inserire = "NO";
$frase .= "L'offerta deve essere un numero intero.<br>";
} # fine if ($verifica_num != "")

$num_calciatori_comprabili = $max_calciatori - $num_calciatori_posseduti;
$surplus = @file("squadra_$nome_utente");
$surplus = $surplus[0];
if ($vecchio_proprietario == $nome_utente and $vecchio_proprietario != $proprietario_vero) {
$surplus = $surplus - $costo + $vecchio_costo;
} # fine if ($vecchio_proprietario == $nome_utente)
$soldi_spendibili = $soldi_iniziali + $surplus - $soldi_spesi;
if ($num_calciatori_comprabili <= 0) {
$inserire = "NO";
$frase .= "Hai raggiunto il valore massimo di calciatori comperabili.<br>";
} # fine if ($num_calciatori_comprabili <= 0)
if ($soldi_spendibili < $valore_offerta) {
$inserire = "NO";
$frase .= "La tua offerta supera i soldi che hai a disposizione.<br>";
} # fine if ($soldi_spendibili <= $valore_offerta)



if ($inserire == "SI") {
if ($sostituire == "NO") {
$posizione == 0;
$num_calciatori++;
} # fine if ($sostituire == "NO")
$file_mercato = fopen("mercato.txt","w+");
flock($file_mercato,2);
for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {

if ($posizione == $num1) {
$adesso = date("YmdHi");
$linea = "$num_calciatore,$nome,$ruolo,$valore_offerta,$nome_utente,$adesso";

if ($vecchio_proprietario) {
$linea .= ",$vecchio_proprietario,$vecchio_costo";
if ($vecchio_proprietario == $nome_utente) {
if ($vecchio_proprietario != $proprietario_vero) { $aggiungi_surplus = $vecchio_costo - $costo; }
else { $aggiungi_surplus = 0; }
} # fine if ($vecchio_proprietario == $nome_utente)
else {
if ($vecchio_proprietario == $proprietario_vero) {
$aggiungi_surplus = $valore_offerta - $vecchio_costo;
} # fine if ($vecchio_proprietario == $proprietario_vero)
else { $aggiungi_surplus = $valore_offerta - $costo; }
} # fine else if ($vecchio_proprietario == $nome_utente)
$lockutente = fopen("squadra_$vecchio_proprietario.lock","w+");
flock($lockutente,2);
$linee = @file("squadra_$vecchio_proprietario");
$filesquadra = fopen("squadra_$vecchio_proprietario","w+");
flock($filesquadra,2);
$num_linee = count($linee);
if ($num_linee < 1) { $num_linee = 1; }
$nuovo_surplus = $linee[0] + $aggiungi_surplus;
$linee[0] = "$nuovo_surplus
";
rewind($filesquadra);
for ($num2 = 0 ; $num2 < $num_linee ; $num2++) {
fwrite($filesquadra,$linee[$num2]);
} # fine for $num2
flock($filesquadra,3);
flock($lockutente,3);
} # fine if ($vecchio_proprietario)

fwrite($file_mercato,"$linea
");
} # fine if ($posizione == $num1)

else {
if ($sostituire == "NO") { $num_linea = $num1 - 1; }
else { $num_linea = $num1; }
fwrite($file_mercato,$calciatori[$num_linea]);
} # fine else if ($posizione == $num1)
} # fine for $num1
flock($file_mercato,3);
fclose($file_mercato);
echo "<html>
<header>
<title> fantacalcio </title>
<meta http-equiv=\"refresh\" content=\"1; url=mercato.php?nome_utente=$nome_utente&pass_fornita=$pass_fornita\">
</header>
<body bgcolor=#ffffff>
Offerta inserita!";
} # fine if ($inserire == "SI");

else {
echo "<html>
<header>
<title> Fantacalcio </title>
</header>
<body bgcolor=#ffffff>";
echo $frase;
} # fine else if ($inserire == "SI");

echo "<center><form method=\"post\" action=\"mercato.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"torna_mercato\" value=\"Torna al mercato\">
</form></center>";



flock($lock,3);

} # fine if ($pass_errata != "SI")
?>


</body>
</html>
